// ============================================================================================================================================
// runs at startup
// ============================================================================================================================================


void setup()
{
  EEPROM.begin(4096);
  
  //set up GPIO pins
  pinMode(PIN_RX, INPUT);
  pinMode(PIN_TX, OUTPUT);
  digitalWrite(PIN_TX, 1); //turn off LED immediately
  pinMode(PIN_SPKR, OUTPUT);
  //required on pico W to disable wifi chip, as the battery voltage pin is also used as the wifi chip's clock pin
  pinMode(25, OUTPUT);
  digitalWrite(25, 1);
  pinMode(PIN_BATTERY, INPUT);
  for(byte i = 0; i < NUM_BUTTONS; i++) { buttons[i].init(); }
  
  //set up LCD and its I2C comms
  Wire.setSCL(PIN_LCD_SCL);
  Wire.setSDA(PIN_LCD_SDA);
  lcd.begin(DOGS164);
  lcd.display(SET_ROM_B);
  lcd.display(CONTRAST, 40);
  lcd.display(VIEW_TOP);
  setupCustomChars();
  lcd.cls();
  
  //load data from EEPROM and check if it's valid
  loadInboxFromEEPROM();
  loadSettingsFromEEPROM();
  if(settings.formatcheck != SETTINGS_FORMATCHECK)
  {
    formatEEPROM();
    lcd.locate(3, 0); lcd.print("INIT");
  }

  //check for button held down on startup
  //hold CLEAR to factory reset
  uint8_t startup_btn = checkButton();
  if(startup_btn == BTN_CLEAR) { promptFactoryReset(); }

  //play startup
  lcd.locate(1, 0); lcd.print("((( lyte");
  lcd.locate(2, 8); lcd.print("byte )))");
  delay(100);
  playTone(72, 50); delay(100);
  playTone(76, 50); delay(100);
  playTone(74, 50); delay(300);
  playTone(79, 0); delay(100);
  playTone(82, 100); delay(500);
  lcd.cls();
  
}

void loop()
{
  lockScreen();
}